@@ -1,3 +1,5 @@
+pub struct Postgres;
+
 #[cfg(feature = "def")]
 #[cfg_attr(docsrs, doc(cfg(feature = "def")))]
 pub mod def;
@@ -17,3 +19,7 @@ pub mod query;
 #[cfg(feature = "writer")]
 #[cfg_attr(docsrs, doc(cfg(feature = "writer")))]
 pub mod writer;
+
+#[cfg(feature = "probe")]
+#[cfg_attr(docsrs, doc(cfg(feature = "probe")))]
+pub mod probe;
