@@ -1,5 +1,5 @@
 use super::{InformationSchema, SchemaQueryBuilder};
-use crate::sqlx_types::{postgres::PgRow, Row};
+use crate::sqlx_types::postgres::PgRow;
 use sea_query::{Expr, Iden, Query, SeaRc, SelectStatement};
 
 #[derive(Debug, sea_query::Iden)]
@@ -64,6 +64,8 @@ pub struct ColumnQueryResult {
 
     pub interval_type: Option<String>,
     pub interval_precision: Option<i32>,
+
+    pub udt_name: Option<String>,
 }
 
 impl SchemaQueryBuilder {
@@ -88,6 +90,7 @@ impl SchemaQueryBuilder {
                 ColumnsField::DatetimePrecision,
                 ColumnsField::IntervalType,
                 ColumnsField::IntervalPrecision,
+                ColumnsField::UdtName,
             ])
             .from((InformationSchema::Schema, InformationSchema::Columns))
             .and_where(Expr::col(ColumnsField::TableSchema).eq(schema.to_string()))
@@ -99,6 +102,7 @@ impl SchemaQueryBuilder {
 #[cfg(feature = "sqlx-postgres")]
 impl From<&PgRow> for ColumnQueryResult {
     fn from(row: &PgRow) -> Self {
+        use crate::sqlx_types::Row;
         Self {
             column_name: row.get(0),
             column_type: row.get(1),
@@ -114,6 +118,7 @@ impl From<&PgRow> for ColumnQueryResult {
             datetime_precision: row.get(11),
             interval_type: row.get(12),
             interval_precision: row.get(13),
+            udt_name: row.get(14),
         }
     }
 }
