@@ -12,4 +12,13 @@ pub mod postgres {
     pub struct PgRow;
 }
 
+pub struct SqlitePool;
+
+pub mod sqlite {
+    pub struct SqliteRow;
+}
+
 pub trait Row {}
+
+#[derive(Debug)]
+pub struct Error;
